--==--==--==--==--==--==--==--==--==--==--==--==--==--==--==--==--==--==--==--==--==--==--==--==--
			--Cloud Tunnel, ver : 0.1.0
			--A maxscript to create clouds
			--by Oormi Creations
			--http://oormi.in
			
			--based on a tutorial by Jonas Ussing [www.duck.dk]
			--http://library.creativecow.net/articles/ussing_jonas/clouds_3dmax.php
			--This script is free for all kinds of uses and modifications
			--Please retain all the names and links if you change it
--==--==--==--==--==--==--==--==--==--==--==--==--==--==--==--==--==--==--==--==--==--==--==--==--

(
clearlistener()
rf = newRolloutFloater "Cloud Tunnel" 200 600

fn getcloudmap =
(
		sfile = getSourceFileName()
		spath = getFilenamePath sfile
		hfile = spath + "CloudOpacityMap1.jpg"
		hext = doesFileExist hfile
		if hext then return hfile
		else messageBox ("The file CloudOpacityMap1.jpg was not found.\nPlease copy it to " + spath + "\nOr select your own mask image.") 
		return undefined
)

--tunnel objects
tunnel = Cylinder heightsegs:40 capsegs:1 sides:15 height:440 radius:45 renderable:off
addmodifier tunnel (turbosmooth iterations:2)
addmodifier tunnel (Noisemodifier scale:40 fractal:on iterations:2 strength:[40,40,40])
addmodifier tunnel (push push_value:-10)
addmodifier tunnel (bend BendAngle:25)

--highlight tunnel
tcopy = copy tunnel
tcopy.pos = [0,0,10]
tcopy.renderable=off

--tunnel cam
tcam = Targetcamera target:(Targetobject())
tcam.pos = [0,0,30]
tcam.target.pos = [0,0,440]
tcam.fov = 45
dum = dummy()
dum.pos = [0,0,-120]
dum.parent = tcam
select tcam
viewport.setType #view_camera

--background & light
backgroundColor = color 87 146 192
om = Omnilight()
om.pos = [300,0,300]
om.ambientOnly = on
om.multiplier = 0.2
om.rgb = color 253 232 199

--main cloud mat
fname = getcloudmap()
	
ctmat1 = Standardmaterial ()
ctmat1.diffuseMap = Noise ()
ctmat1[#Maps][4].type = 1
ctmat1[#Maps][4].size = 100
ctmat1[#Maps][4].thresholdHigh = 0.8
ctmat1[#Maps][4].thresholdLow = 0.2
ctmat1[#Maps][4].levels = 10
ctmat1[#Maps][4].color1 = color 60 90 115
ctmat1.useSelfIllumColor = on
ctmat1.selfIllumColor = color 0 41 70
ctmat1.opacityMap = Mask ()
if fname != undefined then ctmat1[#Maps][14].Mask = Bitmaptexture fileName:fname
ctmat1[#Maps][14].map = Gradient color2pos:1 gradienttype:1
sm = Smoke size:5 exponent:1
ctmat1[#Maps][14].map.MAP1 = sm
ctmat1[#Maps][14].map.MAP2 = sm

meditMaterials[1] = ctmat1

--highlight mat
ctmat2 = copy ctmat1
ctmat2.selfIllumColor = color 242 163 79
meditMaterials[2] = ctmat2

	
--pf source main
mainpf = PF_Source name:(uniquename "CT-PF-Source") X_Coord:493 Y_Coord:0 isSelected:on Logo_Size:45 Emitter_Length:60 Emitter_Width:60 Emitter_Height:0.01 
mainpf.pos = [100,0,0]

particleFlow.BeginEdit()

op1 = Birth Emit_Stop:0 Emit_Start:0 amount:1000
op2 = Position_Object Emitter_Objects:#(tunnel) Random_Seed:12345
op3 = Shape_Facing Look_At_Object:dum Size_Space:0 units:25 ORIENTATION:2 --Random_Seed:(random 1 10000)
op4 = Material_Static Assigned_Material:ctmat1
op5 = DisplayParticles type:6 visible:100
op6 = RenderParticles type:2 visible:100 Split_Type:0

ev1 = Event()
ev1.SetPViewLocation (mainpf.X_Coord+40) (mainpf.Y_Coord+100)
ev1.AppendAction op1
ev1.AppendAction op2
ev1.AppendAction op3
ev1.AppendAction op4
ev1.AppendAction op5
mainpf.AppendAction op6
mainpf.AppendInitialActionList ev1

--pf source highlight
op11 = Birth Emit_Stop:0 Emit_Start:0 amount:1000
op12 = Position_Object Emitter_Objects:#(tcopy) Random_Seed:12345
op13 = Shape_Facing Look_At_Object:dum Size_Space:0 units:25 ORIENTATION:2 --Random_Seed:(random 1 10000)
op14 = Material_Static Assigned_Material:ctmat2
op15 = DisplayParticles type:6 visible:100

ev2 = Event()
ev2.SetPViewLocation (mainpf.X_Coord+10) (mainpf.Y_Coord+260)
ev2.AppendAction op11
ev2.AppendAction op12
ev2.AppendAction op13
ev2.AppendAction op14
ev2.AppendAction op15
mainpf.AppendInitialActionList ev2

particleFlow.endEdit()

--set renderer to DSR
renderers.current = Default_Scanline_Renderer()

fn showpreview =
(
		return render outputSize:[170,70] camera:tcam vfb:off antiAliasing:off filterMaps:off
)


rollout cloudtunnel "Cloud Tunnel 0.1.0" width:200 height:600
(
	local bm1 = bitmap 80 16 color:(color 253 232 199)
	local bm2 = bitmap 80 16 color:(color 0 41 70)
	local bm3 = bitmap 80 16 color:(color 242 163 79)
	local bm4 = bitmap 80 16 color:(color 87 146 192)
	--button btn_create "Create Cloud Tunnel" pos:[20,20] width:160 height:40
	imgTag  pre pos:[8,10] width:170 height:70 tooltip:"Click to update"
	label lbl1 "Count" pos:[20,90] width:80 height:20
	spinner spn_count "" pos:[100,90] width:80 height:16 range:[0,100000,1000] type:#integer scale:10
	label lbl2 "Size" pos:[20,120] width:80 height:20
	spinner spn_size "" pos:[100,120] width:80 height:16 range:[0,1000,25] type:#float scale:0.1
	label lbl3 "Seed" pos:[20,150] width:80 height:20
	spinner spn_seed "" pos:[100,150] width:80 height:16 range:[0,100000,12345] type:#integer scale:1
	label lbl4 "Light" pos:[20,180] width:80 height:20
	spinner spn_om "" pos:[100,180] width:80 height:16 range:[0,100,0.2] type:#float scale:0.05
	label lbl5 "Light Color" pos:[20,210] width:80 height:20
	--colorPicker cp_om "" pos:[100,210] width:80 height:20 color:(color 253 232 199) modal:false
	imgTag  cp_om pos:[100,210] width:80 height:16 bitmap:bm1
	label lbl6 "Cloud Color" pos:[20,240] width:80 height:20
	--colorPicker cp_cloud "" pos:[100,240] width:80 height:20 color:(color 0 41 70)
	imgTag  cp_cloud pos:[100,240] width:80 height:16 bitmap:bm2
	label lbl7 "Highlight Color" pos:[20,270] width:80 height:20
	--colorPicker cp_hi "" pos:[100,270] width:80 height:20 color:(color 242 163 79)
	imgTag  cp_hi pos:[100,270] width:80 height:16 bitmap:bm3
	label lbl8 "Sky Color" pos:[20,300] width:80 height:20
	--colorPicker cp_sky "" pos:[100,300] width:80 height:20 color:(color 87 146 192)
	imgTag  cp_sky pos:[100,300] width:80 height:16 bitmap:bm4
	pickButton btn_em "Emitter Object" pos:[20,330] width:160 height:40
	pickButton btn_hi "Highlight Object" pos:[19,380] width:160 height:40
	button btn_mask "Mask Map" pos:[20,430] width:160 height:40
	
	on cloudtunnel open  do pre.bitmap = showpreview()
	
	on pre click do pre.bitmap = showpreview()

	on spn_count entered  do
	(
		op1.amount = spn_count.value
		op11.amount = spn_count.value
		pre.bitmap = showpreview()
	)
	on spn_size entered do
	(
		op3.units = spn_size.value
		op13.units = spn_size.value
		pre.bitmap = showpreview()
	)
	on spn_seed entered do
	(
		op2.Random_Seed= spn_seed.value
		op12.Random_Seed= spn_seed.value
		pre.bitmap = showpreview()
	)
	on spn_om entered do
	(
		om.multiplier = spn_om.value
		pre.bitmap = showpreview()
	)
	on cp_om click do
	(
		col = colorPickerDlg om.rgb "Pick Light Color"
		if col!=undefined then
		(
			om.rgb=col
			cp_om.bitmap = bitmap 80 16 color: om.rgb 
			pre.bitmap = showpreview()
		)
	)
	on cp_cloud click do
	(
		col = colorPickerDlg ctmat1.selfIllumColor "Pick Cloud Color"
		if col!=undefined then
		(
			ctmat1.selfIllumColor=col
			cp_cloud.bitmap = bitmap 80 16 color: ctmat1.selfIllumColor 
			pre.bitmap = showpreview()
		)
	
	)
	on cp_hi click do
	(
		col = colorPickerDlg ctmat2.selfIllumColor "Pick Highlight Color"
		if col!=undefined then
		(
			ctmat2.selfIllumColor=col
			cp_hi.bitmap = bitmap 80 16 color: ctmat2.selfIllumColor
			pre.bitmap = showpreview()
		)
	
	)
	on cp_sky click do
	(
		col = colorPickerDlg backgroundColor "Pick Sky Color"
		if col!=undefined then
		(
			backgroundColor=col
			cp_sky.bitmap = bitmap 80 16 color: backgroundColor 
			pre.bitmap = showpreview()
		)
	
	)
	on btn_em picked obj do
	(
		if obj != undefined then 
		(
			op2.Emitter_Objects = #(obj)
			btn_em.text = "Emitter:"+obj.name
			obj.renderable = off
			pre.bitmap = showpreview()
		)
	)
	on btn_hi picked obj do
	(
		if obj != undefined then 
		(
			op12.Emitter_Objects = #(obj)
			btn_hi.text = "Highlight:"+obj.name
			obj.renderable = off
			pre.bitmap = showpreview()
		)
	)
	on btn_mask pressed  do
	(
		custommask = selectBitMap caption:"Select the Mask Image"
		if custommask != undefined then
		(
			ctmat1[#Maps][14].Mask = Bitmaptexture fileName:custommask.filename
			ctmat2[#Maps][14].Mask = Bitmaptexture fileName:custommask.filename
			btn_mask.text = "Mask:"+(filenameFromPath custommask.filename)
			pre.bitmap = showpreview()
		)
	)

)

rollout cthelp "Help & About"
(
	hyperlink hlink1 "Online Help" pos:[65,10] address:"http://oormi.in/software/CT-010-Help-01.htm" color: green
	label lab1 "Cloud Tunnel 0.1.0" pos:[50,30]
	label lab3 "based on a tutorial by Jonas Ussing" pos:[8,50]
	hyperlink hlink4 "http://jussing.dk" address:"http://jussing.dk" color: yellow pos:[55,70]
	label lab2 "by Oormi Creations " pos:[50,90]
	hyperlink hlink2 "http://oormi.in" address:"http://oormi.in" color: yellow pos:[55,110]
	hyperlink hlink3 "oormicreations@gmail.com" address:"mailto:oormicreations@gmail.com" color: orange pos:[28,130]
)

rollout ctpromos "More Scripts" height:100
(
	hyperlink hlink1 "MaxMounts : Create Mountains" pos:[15,5] address:"http://oormi.in/software/maxmounts-01.html" color: green
	hyperlink hlink2 "MaxGrass : Create Animated Grass" pos:[10,25] address:"http://oormi.in/software/maxgrass-01.html" color: orange
	hyperlink hlink3 "Free Scripts by Oormi Creations" address:"http://oormi.in/software-01.html" color: yellow
)


addRollout cloudtunnel  	rf
addRollout cthelp 			rf rolledUp:true
addRollout ctpromos 		rf rolledUp:true
)
